.. currentmodule:: obspy.clients.fdsn
.. automodule:: obspy.clients.fdsn

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       client.Client
       routing.routing_client.RoutingClient
       mass_downloader.download_helpers._SlotsEqualityComparisionObject

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       client
       routing
       routing.routing_client
       routing.routing_client.BaseRoutingClient
       routing.eidaws_routing_client
       routing.eidaws_routing_client.EIDAWSRoutingClient
       routing.federator_routing_client
       routing.federator_routing_client.FederatorRoutingClient
       mass_downloader
       mass_downloader.domain
       mass_downloader.mass_downloader.MassDownloader
       mass_downloader.restrictions
       mass_downloader.download_helpers

    .. comment to end block
